@@ -1,13 +1,13 @@
 pub mod create_payment;
-pub mod create_payment_index;
-pub mod create_task_index;
+pub mod create_payment_namespace;
+pub mod create_task_namespace;
 pub mod initialize_program;
 pub mod process_task;
 pub mod utils;
 
 pub use create_payment::*;
-pub use create_payment_index::*;
-pub use create_task_index::*;
+pub use create_payment_namespace::*;
+pub use create_task_namespace::*;
 pub use initialize_program::*;
 pub use process_task::*;
 pub use utils::*;
