@@ -1,15 +1,17 @@
 mod authority;
 mod config;
 mod payment;
+mod payment_namespace;
 mod role;
 mod task;
-mod task_index;
+mod task_namespace;
 mod treasury;
 
 pub use authority::*;
 pub use config::*;
 pub use payment::*;
+pub use payment_namespace::*;
 pub use role::*;
 pub use task::*;
-pub use task_index::*;
+pub use task_namespace::*;
 pub use treasury::*;
